<?php
require_once("/usr/local/www/berogui/includes/Helper/HelperHtml.php");

class Vpn {
	/* [ATTRIBUTS] */
	private $_m;

	private	$_isRequestRejected	= false,
					$_reasonRejected		= null;

	private $_data 				= [],
					$_parameters 	= [];

	private $_tabs = [
						1 => [
							'function' 	=> '_displayServerSettingsTab',
							'title' 		=> 'VPN_SERVERS_SETTINGS_TAB',
						],
						2 => [
							'function'	=> '_displayClientSettingsTab',
							'title' 		=> 'VPN_CLIENTS_SETTINGS_TAB',
						],
						3 => [
							'function'	=> '_displayDownloadClientConfTab', 
							'title' 		=> 'VPN_CLIENT_CONF_DOWNLOAD_TAB',
						],
					];

	/* [CONSTRUCTOR] */
	function __construct($m, $get = [], $post = [], $session = []) {
		$this->_m = $m;

		// load beroAri / beroConf classes -> should be avoided and given as argument of the construct method
		$bc = new beroConf('root');

		require_once("/usr/local/www/berogui/misc/database.php");
		$ba = new beroAri();

		// get data
		require_once("/usr/local/www/berogui/modules/Vpn/vpn_helper.php");
		$this->_parameters = require("/usr/local/www/berogui/modules/Vpn/vpn_parameters.php");
		$this->_parameters = $this->_parameters['load']($bc, $this->_parameters);

		$this->_data = VpnHelper::getData($ba, $this->_parameters);

		// manage tabs
		if (empty($this->_data['clients'])) {
			unset($this->_tabs[2]);
		}
		if (!($bc->get('root', 'is-vpn-running'))) {
			unset($this->_tabs[3]);
		}

		// set error
		if (isset($get['error'])) {
			$this->_isRequestRejected = true;
			switch ($get['error']) {
				case '1':
					$this->_reasonRejected = Helper::displayErrorMessage($get['request'], $get['checkor'], $get['key']);
					break;
				case '2':
					$this->_reasonRejected = Helper::displayErrorMessage("Invalid input data: {$get['reason']}");
					break;
				default:
					$this->_reasonRejected = "Unknown error";
					break;
			}
		}
	}

	/* [PUBLIC METHODS] */
	public function display() {
		$name = "VPN_TITLE_DIS";
		include('./includes/header.php');

		// errors
		if ($this->_isRequestRejected) {
			$ret .= $this->_reasonRejected;
		}

		// tabs
		$menu = '';
		$content = '';
		foreach ($this->_tabs as $id => $tab) {
			$menu .= "\t\t\t<li><a href='#tabs-$id'>". constant($tab['title']) ."</a></li>\n";

			$function = $tab['function'];
			$content .= $this->$function($id);
		}

		$msg = "<div id='vpn_error' class='text-center' style='color:red;font-size:15;margin-top:20px; margin-bottom:-20px;'></div>\n";
		$ret .= HelperHtml::buildTabs('tabs', $msg, $menu, $content);

		return $ret;
	}

	/* [PRIVATE METHODS] */
	private function _displayDownloadClientConfTab($tab) {
		ob_start();
		?>
		<!-- Download Client Conf Tab --!>
		<div id='tabs-<?php echo $tab; ?>'>
			<div class="panel panel-default" style="max-width:600px; margin:auto; margin-top: 20px;">
				<div class="panel-heading text-center lead">
					<?php echo VPN_CLIENT_CONF_DOWNLOAD_DIS ."\n"; ?>
				</div>
				<div class="panel-body text-center">
					<input type='button' class='btn btn-default' value='<?php echo VPN_CLIENT_CONF_DOWNLOAD_BUTTON ?>'
						onclick="window.location.href='misc/files_download.php?option=vpn-client-conf-dl'">
				</div>
			</div>
		</div>
		<?php
		return ob_get_clean() ."\n";
	}

	private function _displayClientSettingsTab($tab) {
		$client = $this->_parameters['client'];
		// build content
		$content = '';
		foreach ($client as $key => $values) {
			$function = $values['display'];
			$content .= HelperHtml::$function($key, $this->_data['clients'][0][$key], $values, "\t\t\t");
		}
		// build tab
		return HelperHtml::tab($tab, null, null, $content, null, "\t\t");
	}

	private function _displayServerSettingsTab($tab) {
		// display form
		$server = $this->_parameters['server'];
		ob_start();
		?>
		<!-- Settings Tab --!>
		<div id='tabs-<?php echo $tab; ?>'>
			<script type="text/javascript">
				$(document).ready(function () {
					$('#id_vpn_settings').submit(function (evt) {
						// TODO: Does the checkor can be enhanced ?
						var ipRange = $('#id_<?php echo $server['iprange']['key']; ?>').val().split('.');
						if (ipRange[3] == '0') {
							var ipNetmask = $('#id_<?php echo $server['ipnetmask']['key']; ?>').val().split('.');
							if (ipNetmask[3] == '0') {
								return;
							}
							else {
								$('#vpn_error').html("<?php echo VPN_IPNETMASK_ERROR; ?>");
							}
					}
						else {
							$('#vpn_error').html("<?php echo VPN_IPRANGE_ERROR; ?>");
						}
						evt.preventDefault();
					});
					$('#id_vpn_settings').change(function() {
						$('#vpn_error').html('');
					});
					$('.btn.btn-default.action').click(function(evt) {
						var action = $(evt.target).attr('value2');
						if (action == 'delete' && !confirm('<?php echo VPN_CONFIRM_DELETE_VPN; ?>')) {
							evt.preventDefault();
							return;
						}
						$(evt.target).val(action);
					});
				});
			</script>
			<form name='name_vpn_settings' id='id_vpn_settings' class="form-horizontal" style='magin-bottom:10px;' action='modules/Vpn/vpn_submit.php' method='POST' ENCTYPE="multipart/form-data">
				<input type='hidden' name='idkey' value='0'> 
				<input type='hidden' name='isMainVpnExist' value='<?php echo (isset($this->_data['servers'][0]) ? '1' : '0'); ?>'>
		<?php
		$ret = 	ob_get_clean() ."\n"
					.	HelperHtml::validateJavascript('id_vpn_settings', array_intersect_key($server, array_flip(array('iprange', 'ipnetmask', 'port'))));

		foreach ($server as $key => $params) {
			$function = $params['display'];
			$ret .= HelperHtml::$function($key, $this->_data['servers'][0][$key], $params, "\t\t\t\t");
		}

		ob_start();
		?>
				<div class='text-center'>
					<input type='submit' class='btn btn-default action' id='btn-save-vpn' name='action' value='<?php echo BUTTON_SAVE ?>' value2='save'>
		<?php if (file_exists('/etc/openvpn/client.conf')) { ?>
					<input type='submit' class='btn btn-default action' id='btn-delete-vpn' name='action' value='<?php echo BUTTON_DELETE ?>' value2='delete'>
		<?php	} ?>
				</div>
			</form>
			<div class='text-center' style='margin-top:20px;'><i><?php echo REQUIRED_FIELDS ?></i></div>
		</div>
		<?php

		return $ret. ob_get_clean() ."\n";
	}
}
?>
